[![pipeline status](https://gitlab.com/fvafrcu/fritools/badges/master/pipeline.svg)](https://gitlab.com/fvafrcu/fritools/-/commits/master)    
[![coverage report](https://gitlab.com/fvafrcu/fritools/badges/master/coverage.svg)](https://gitlab.com/fvafrcu/fritools/-/commits/master)
<!-- 
    [![Build Status](https://travis-ci.org/fvafrcu/fritools2.svg?branch=master)](https://travis-ci.org/fvafrcu/fritools2)
    [![Coverage Status](https://codecov.io/github/fvafrcu/fritools2/coverage.svg?branch=master)](https://codecov.io/github/fvafrcu/fritools2?branch=master)
-->
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/fritools2)](https://cran.r-project.org/package=fritools2)
[![RStudio_downloads_monthly](https://cranlogs.r-pkg.org/badges/fritools2)](https://cran.r-project.org/package=fritools2)
[![RStudio_downloads_total](https://cranlogs.r-pkg.org/badges/grand-total/fritools2)](https://cran.r-project.org/package=fritools2)

<!-- README.md is generated from README.Rmd. Please edit that file -->



# fritools2
## Introduction

After installation, please read the help page:

```r
help("fritools2-package", package = "fritools2")
```


```
#> Utilities for the Forest Research Institute of the State
#> Baden-Wuerttemberg
#> 
#> Description:
#> 
#>      Miscellaneous utilities, tools and helper functions.
#> 
#> Details:
#> 
#>      You will find the details in
#>      'vignette("An_Introduction_to_fritools", package = "fritools2")'.
```

## Installation

You can install fritools2 from gitlab via:


```r
if (! require("remotes")) install.packages("remotes")
remotes::install_gitlab("fvafrcu/fritools2")
```


