#' Utilities for the Forest Research Institute of the State
#' Baden-Wuerttemberg
#'
#' Miscellaneous utilities, tools and helper functions.
#'
#' You will find the details in\cr
#' \code{vignette("An_Introduction_to_fritools", package = "fritools2")}.
#'
#' @name fritools2-package
#' @aliases fritools2-package
#' @docType package
#' @keywords package
NULL
